@@ -2,7 +2,6 @@ import requests
 from urllib import urlencode
 import json
 
-
 class Client(object):
     def __init__(self, url):
         """
@@ -10,27 +9,60 @@ class Client(object):
         :Args:
          - url: This is where the BrowserMob Proxy lives
         """
-        self.host = url
+        self.host = "http://" + url
         resp = requests.post('%s/proxy' % self.host, urlencode(''))
         jcontent = json.loads(resp.content)
         self.port = jcontent['port']
         url_parts = self.host.split(":")
-        self.proxy = url_parts[0] + ":" + url_parts[1] + ":" + str(self.port)
+        self.proxy = url_parts[1][2:] + ":" + str(self.port)
 
-    def headers(self, headers):
+    def close(self):
         """
-        This sets the headers that will set by the proxy on all requests
-        :Args:
-         - headers: this is a dictionary of the headers to be set
-         """
-        if not isinstance(headers, dict):
-            raise TypeError("headers needs to be dictionary")
-
-        r = requests.post(url='%s/proxy/%s/headers' % (self.host, self.port),
-                          data=json.dumps(headers),
-                          headers={'content-type': 'application/json'})
+        shuts down the proxy and closes the port
+        """
+        r = requests.delete('%s/proxy/%s' % (self.host, self.port))
         return r.status_code
 
+    # webdriver integration
+    # ...as a proxy object
+    def selenium_proxy(self):
+        """
+        Returns a Selenium WebDriver Proxy class with details of the HTTP Proxy
+        """
+        from selenium import webdriver
+        return webdriver.Proxy({
+            "httpProxy": self.proxy,
+            "sslProxy": self.proxy,
+        })
+
+    def webdriver_proxy(self):
+        """
+        Returns a Selenium WebDriver Proxy class with details of the HTTP Proxy
+        """
+        return self.selenium_proxy()
+
+    # ...as a capability
+    def add_to_capabilities(self, capabilities):
+        """
+        Adds an 'proxy' entry to a desired capabilities dictionary with the
+        BrowserMob proxy information
+        """
+        capabilities['proxy'] = {'proxyType': "MANUAL",
+                                 'httpProxy': self.proxy}
+
+    def add_to_webdriver_capabilities(self, capabilities):
+        self.add_to_capabilities(capabilities)
+
+    # browsermob proxy api
+    @property
+    def har(self):
+        """
+        Gets the HAR that has been recorded
+        """
+        r = requests.get('%s/proxy/%s/har' % (self.host, self.port))
+
+        return r.json()
+
     def new_har(self, ref=None):
         """
         This sets a new HAR to be recorded
@@ -42,7 +74,10 @@ class Client(object):
         else:
             payload = {}
         r = requests.put('%s/proxy/%s/har' % (self.host, self.port), payload)
-        return (r.status_code, r.json)
+        if r.status_code == 200:
+            return (r.status_code, r.json())
+        else:
+            return (r.status_code, None)
 
     def new_page(self, ref=None):
         """
@@ -58,48 +93,6 @@ class Client(object):
                          payload)
         return r.status_code
 
-    @property
-    def har(self):
-        """
-        Gets the HAR that has been recorded
-        """
-        r = requests.get('%s/proxy/%s/har' % (self.host, self.port))
-
-        return r.json
-
-    def selenium_proxy(self):
-        """
-        Returns a Selenium WebDriver Proxy class with details of the HTTP Proxy
-        """
-        from selenium import webdriver
-        return webdriver.Proxy({"httpProxy": self.proxy})
-
-    def webdriver_proxy(self):
-        """
-        Returns a Selenium WebDriver Proxy class with details of the HTTP Proxy
-        """
-        return self.selenium_proxy()
-
-    def add_to_webdriver_capabilities(self, capabilities):
-        """
-        Adds an 'proxy' entry to a desired capabilities dictionary with the
-        BrowserMob proxy information
-        """
-        capabilities['proxy'] = {'proxyType': 'manual',
-                                 'httpProxy': self.proxy}
-
-    def whitelist(self, regexp, status_code):
-        """
-        Sets a list of URL patterns to whitelist
-        :Args:
-         - regex: a comma separated list of regular expressions
-         - status_code: the HTTP status code to return for URLs that do not
-           match the whitelist
-        """
-        r = requests.put('%s/proxy/%s/whitelist' % (self.host, self.port),
-                         urlencode({'regex': regexp, 'status': status_code}))
-        return r.status_code
-
     def blacklist(self, regexp, status_code):
         """
         Sets a list of URL patterns to blacklist
@@ -110,7 +103,19 @@ class Client(object):
 
         """
         r = requests.put('%s/proxy/%s/blacklist' % (self.host, self.port),
-                         urlencode({'regex': regexp, 'status': status_code}))
+                         {'regex': regexp, 'status': status_code})
+        return r.status_code
+
+    def whitelist(self, regexp, status_code):
+        """
+        Sets a list of URL patterns to whitelist
+        :Args:
+         - regex: a comma separated list of regular expressions
+         - status_code: the HTTP status code to return for URLs that do not
+           match the whitelist
+        """
+        r = requests.put('%s/proxy/%s/whitelist' % (self.host, self.port),
+                         {'regex': regexp, 'status': status_code})
         return r.status_code
 
     def basic_authentication(self, domain, username, password):
@@ -126,6 +131,42 @@ class Client(object):
                           headers={'content-type': 'application/json'})
         return r.status_code
 
+    def headers(self, headers):
+        """
+        This sets the headers that will set by the proxy on all requests
+        :Args:
+         - headers: this is a dictionary of the headers to be set
+         """
+        if not isinstance(headers, dict):
+            raise TypeError("headers needs to be dictionary")
+
+        r = requests.post(url='%s/proxy/%s/headers' % (self.host, self.port),
+                          data=json.dumps(headers),
+                          headers={'content-type': 'application/json'})
+        return r.status_code
+
+    def response_interceptor(self, js):
+        """
+        Executes the javascript against each response
+        :Args:
+         - js: the javascript to execute
+        """
+        r = requests.post(url='%s/proxy/%s/interceptor/response' % (self.host, self.port),
+                  data=js,
+                  headers={'content-type': 'x-www-form-urlencoded'})
+        return r.status_code
+
+    def request_interceptor(self, js):
+        """
+        Executes the javascript against each request
+        :Args:
+         - js: the javascript to execute
+        """
+        r = requests.post(url='%s/proxy/%s/interceptor/request' % (self.host, self.port),
+                  data=js,
+                  headers={'content-type': 'x-www-form-urlencoded'})
+        return r.status_code
+
     LIMITS = {
         'upstream_kbps': 'upstreamKbps',
         'downstream_kbps': 'downstreamKbps',
@@ -153,7 +194,39 @@ class Client(object):
             raise KeyError("You need to specify one of the valid Keys")
 
         r = requests.put('%s/proxy/%s/limit' % (self.host, self.port),
-                         urlencode(params))
+                         params)
+        return r.status_code
+
+    TIMEOUTS = {
+        'request': 'requestTimeout',
+        'read': 'readTimeout',
+        'connection': 'connectionTimeout',
+        'dns': 'dnsCacheTimeout'
+    }
+
+    def timeouts(self, options):
+        """
+        Configure various timeouts in the proxy
+        :Args:
+         - options: A dictionary with all the details you want to set.
+                        request - request timeout (in seconds)
+                        read - read timeout (in seconds)
+                        connection - connection timeout (in seconds)
+                        dns - dns lookup timeout (in seconds)
+        """
+        params = {}
+
+        for (k, v) in options.items():
+            if k not in self.TIMEOUTS:
+                raise KeyError('invalid key: %s' % k)
+
+            params[self.TIMEOUTS[k]] = int(v)
+
+        if len(params.items()) == 0:
+            raise KeyError("You need to specify one of the valid Keys")
+
+        r = requests.put('%s/proxy/%s/timeout' % (self.host, self.port),
+                         params)
         return r.status_code
 
     def remap_hosts(self, address, ip_address):
@@ -169,9 +242,47 @@ class Client(object):
                           headers={'content-type': 'application/json'})
         return r.status_code
 
-    def close(self):
+    def wait_for_traffic_to_stop(self, quiet_period, timeout):
         """
-        shuts down the proxy and closes the port
+        Waits for the network to be quiet
+        :Args:
+         - quiet_period - number of seconds the network needs to be quiet for
+         - timeout - max number of seconds to wait
         """
-        r = requests.delete('%s/proxy/%s' % (self.host, self.port))
+        r = requests.put('%s/proxy/%s/wait' % (self.host, self.port),
+                 {'quietPeriodInMs': quiet_period, 'timeoutInMs': timeout})
         return r.status_code
+
+    def clear_dns_cache(self):
+        """
+        Clears the DNS cache associated with the proxy instance
+        """
+        r = requests.delete('%s/proxy/%s/dns/cache' % (self.host, self.port))
+        return r.status_code
+
+    def rewrite_url(self, match, replace):
+        """
+        Rewrites the requested url.
+        :Args:
+         - match - a regex to match requests with
+         - replace - a string to replace the matches with
+        """
+        params = {
+            "matchRegex": match,
+            "replace": replace
+        }
+        r = requests.put('%s/proxy/%s/rewrite' % (self.host, self.port),
+                         params)
+        return r.status_code
+
+    def retry(self, retry_count):
+        """
+        Retries. No idea what its used for, but its in the API...
+        :Args:
+         - retry_count - the number of retries
+        """
+        r = requests.put('%s/proxy/%s/retry' % (self.host, self.port),
+                 {'retrycount': retry_count})
+        return r.status_code
+
+
