@@ -4,13 +4,12 @@ import sys
 
 
 def setup_module(module):
-    sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
-
+    sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
 
 class TestClient(object):
     def setup_method(self, method):
         from browsermobproxy.client import Client
-        self.client = Client("http://localhost:9090")
+        self.client = Client("localhost:9090")
 
     def teardown_method(self, method):
         self.client.close()
@@ -126,7 +125,7 @@ class TestClient(object):
         with pytest.raises(KeyError):
             self.client.limits({})
 
-    def test_limits_key_no_value(self):
+    def test_limits_all_key_values(self):
         """
         /proxy/:port/limits
         can send all 3 at once based on the proxy implementation
@@ -135,6 +134,16 @@ class TestClient(object):
         status_code = self.client.limits(limits)
         assert(status_code == 200)
 
+    def test_rewrite(self):
+        """
+        /proxy/:port/rewrite
+
+        """
+        match = "/foo"
+        replace = "/bar"
+        status_code = self.client.rewrite_url(match, replace)
+        assert(status_code == 200)
+
     def test_close(self):
         """
         /proxy/:port
@@ -144,3 +153,95 @@ class TestClient(object):
         assert(status_code == 200)
         status_code = self.client.close()
         assert(status_code == 500)
+
+    def test_response_interceptor_with_parsing_js(self):
+        """
+        /proxy/:port/interceptor/response
+        """
+        js = 'alert("foo")'
+        status_code = self.client.response_interceptor(js)
+        assert(status_code == 200)
+
+    def test_response_interceptor_with_invalid_js(self):
+        """
+        /proxy/:port/interceptor/response
+        """
+        js = 'alert("foo"'
+        status_code = self.client.response_interceptor(js)
+        assert(status_code == 500)
+
+    def test_request_interceptor_with_parsing_js(self):
+        """
+        /proxy/:port/interceptor/request
+        """
+        js = 'alert("foo")'
+        status_code = self.client.request_interceptor(js)
+        assert(status_code == 200)
+
+    def test_request_interceptor_with_invalid_js(self):
+        """
+        /proxy/:port/interceptor/request
+        """
+        js = 'alert("foo"'
+        status_code = self.client.request_interceptor(js)
+        assert(status_code == 500)
+
+    def test_timeouts_invalid_timeouts(self):
+        """
+        /proxy/:port/timeout
+        pre-sending checking that the parameter is correct
+        """
+        with pytest.raises(KeyError):
+            self.client.timeouts({"hurray": "explosions"})
+
+    def test_timeouts_key_no_value(self):
+        """
+        /proxy/:port/timeout
+        pre-sending checking that a parameter exists
+        """
+        with pytest.raises(KeyError):
+            self.client.timeouts({})
+
+    def test_timeouts_all_key_values(self):
+        """
+        /proxy/:port/timeout
+        can send all 3 at once based on the proxy implementation
+        """
+        timeouts = {"request": 2, "read": 2, "connection": 2, "dns": 3}
+        status_code = self.client.timeouts(timeouts)
+        assert(status_code == 200)
+
+    def test_remap_hosts(self):
+        """
+        /proxy/:port/hosts
+        """
+        status_code = self.client.remap_hosts("example.com", "1.2.3.4")
+        assert(status_code == 200)
+
+    def test_wait_for_traffic_to_stop(self):
+        """
+        /proxy/:port/wait
+        """
+        status_code = self.client.wait_for_traffic_to_stop(2000, 10000)
+        assert(status_code == 200)
+
+    def test_clear_dns_cache(self):
+        """
+        /proxy/:port/dns/cache
+        """
+        status_code = self.client.clear_dns_cache()
+        assert(status_code == 200)
+
+    def test_rewrite_url(self):
+        """
+        /proxy/:port/rewrite
+        """
+        status_code = self.client.rewrite_url('http://www.facebook\.com', 'http://microsoft.com')
+        assert(status_code == 200)
+
+    def test_retry(self):
+        """
+        /proxy/:port/retry
+        """
+        status_code = self.client.retry(4)
+        assert(status_code == 200)
